@@ -113,25 +113,20 @@ class GitIssuePublisher(Publisher):
             "\n**Code Vulnerability:**\n",
             f"- **Score:** {data['codeVulnerability']['score']} {data['codeVulnerability']['emoji']}",
             f"  *{data['codeVulnerability']['comment']}*\n",
-            "\n**SOLID Principles Analysis:**\n",
-            "| Principle | Score | Comment |\n",
-            "|-----------|-------|---------|"
+            "\n**SOLID Principles Analysis:**\n"
         ]
 
         for principle, details in data['codeSOLID'].items():
-            principle_name = principle.replace('_', ' ').title()
-            score_emoji = f"{details['score']} {details['emoji']}"
-            comment = details['comment']
-            # Ensure proper Markdown escaping to handle special characters in comments
-            comment = comment.replace('|', '\\|').replace('\n', ' ')
-            report.append(f"| {principle_name} | {score_emoji} | {comment} |\n")
+            report.append(f"- **{principle.replace('_', ' ').title()}**")
+            report.append(f"  - **Score:** {details['score']} {details['emoji']}")
+            report.append(f"  *{details['comment']}*\n")
 
 
         return '\n'.join(report)
 
-    def append_data_to_comment(self, existing_body: str, adherence: Dict[str, Any]) -> str:
+        def append_data_to_comment(self, existing_body: str, adherence: Dict[str, Any]) -> str:
         """
-        Appends adherence data to the existing comment body using an XY diagram with emojis.
+        Appends adherence data to the existing comment body using a Mermaid XY diagram.
 
         :param existing_body: The existing comment body.
         :param adherence: A dictionary with adherence score details.
@@ -139,59 +134,51 @@ class GitIssuePublisher(Publisher):
         """
         # Extract existing data points from the comment
         data_points = self.extract_data_points(existing_body)
-        data_points.append((self.sha[:7], adherence['score'], adherence['emoji']))
+        data_points.append((self.sha, adherence['score']))
 
-        # Generate the new XY diagram
-        xy_diagram = self.generate_xy_diagram(data_points)
+        # Generate the new Mermaid diagram
+        mermaid_diagram = self.generate_mermaid_diagram(data_points)
 
         # Update the comment with the new diagram
         updated_body = existing_body.split("\n**Adherence Scores History:**")[0]
-        updated_body += "\n**Adherence Scores History:**\n" + xy_diagram
+        updated_body += "\n**Adherence Scores History:**\n" + mermaid_diagram
         return updated_body
 
-    def generate_xy_diagram(self, data_points: List[tuple]) -> str:
+    def generate_mermaid_diagram(self, data_points: List[tuple]) -> str:
         """
-        Generates a simple XY diagram using emojis as data points.
+        Generates a Mermaid diagram using data points.
 
-        :param data_points: A list of tuples containing commit SHAs, scores, and emojis.
-        :return: A string representing the XY diagram.
+        :param data_points: A list of tuples containing commit SHAs and scores.
+        :return: A string representing the Mermaid diagram.
         """
-        max_score = max(score for _, score, _ in data_points)
-        diagram = ["```\n    +---+---+---+---+---+---+---+---+---+---+---+ (Score)"]
-        for i in range(max_score, 0, -1):
-            line = f"{str(i).rjust(2)} | " + ''.join(
-                data_point[2] if data_point[1] >= i else '   '
-                for data_point in sorted(data_points, key=lambda x: x[1])
-            )
-            diagram.append(line)
-        diagram.append("    +---+---+---+---+---+---+---+---+---+---+---+\n")
-        diagram.append("       " + "   ".join(dp[0] for dp in sorted(data_points, key=lambda x: x[1])) + " (SHA)")
-        diagram.append("```")
+        diagram = ['```mermaid', 'graph TD']
+        for sha, score in data_points:
+            diagram.append(f"A({sha[:7]}) -- {score} --> B({score})")
+        diagram.append('```')
         return '\n'.join(diagram)
 
     def extract_data_points(self, body: str) -> List[tuple]:
         """
-        Extracts data points from the comment body.
+        Extracts data points from the Mermaid diagram in the comment body.
 
         :param body: The comment body.
-        :return: A list of tuples with commit SHAs, scores, and emojis.
+        :return: A list of tuples with commit SHAs and scores.
         """
         lines = body.split("\n")
         data_points = []
-        start_extracting = False
+        parsing = False
         for line in lines:
-            if line.strip().startswith("+---"):  # Start of the diagram
-                start_extracting = True
+            if 'graph TD' in line:
+                parsing = True
                 continue
-            if start_extracting:
-                if line.strip().startswith("```"):  # End of the diagram
+            if parsing:
+                if line.startswith('```'):
                     break
-                parts = line.split('|')
-                if len(parts) > 2:  # Data point lines
-                    sha_part = parts[0].strip()
-                    for idx, part in enumerate(parts[1:], 1):
-                        if part.strip():  # Contains an emoji
-                            data_points.append((sha_part, idx, part.strip()))
+                parts = line.split('--')
+                if len(parts) == 2:
+                    sha = parts[0].strip('A()')
+                    score = parts[1].split(' --> B')[0].strip()
+                    data_points.append((sha, int(score)))
         return data_points
     
 
